.. github-track documentation master file, created by
   sphinx-quickstart.

Welcome to github-track's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   examples
   reference


